#
# spec file for package python-netifaces
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2011 Novell
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{?sle15_python_module_pythons}
Name:           python-netifaces
Version:        0.11.0
Release:        2.3
Summary:        Portable network interface information
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/al45tair/netifaces
Source0:        https://pypi.io/packages/source/n/netifaces/netifaces-%{version}.tar.gz
Source2:        https://raw.githubusercontent.com/al45tair/netifaces/master/test.py
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%python_subpackages

%description
netifaces provides a (hopefully portable-ish) way for Python programmers to
get access to a list of the network interfaces on the local machine, and to
obtain the addresses of those network interfaces.

The package has been tested on Mac OS X, Windows XP, Windows Vista, Linux and
Solaris. On Windows, it is currently not able to retrieve IPv6 addresses,
owing to shortcomings of the Windows API.

It should work on other UNIX-like systems provided they implement either
getifaddrs() or support the SIOCGIFxxx socket options, although the data
provided by the socket options is normally less complete.

%prep
%setup -q -n netifaces-%{version}
cp %{SOURCE2} .

%build
%python_build

%install
%python_install

%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitearch} $python test.py | grep 'Interface lo'

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitearch}/*

%changelog
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Sat Jul 17 2021 Dirk Müller <dmueller@suse.com>
- update to 0.11.0:
  * Fixing netmask calculation for IPv6
  * segfault when trying to access netifaces.ifaddresses
  * Interpret missing gateway priority, handle some out of order metrics
* Fri May 24 2019 pgajdos@suse.com
- version update to 0.10.9
  * Fixed a bug that in certain circumstances could lead to an infinite
    loop in netifaces.gateways() (thanks asomers).
  * Fixed a memory management bug in an error path (thanks NicoPy).
- created a small test
* Mon Sep 10 2018 dmueller@suse.com
- update to 0.10.7:
  * move to github
* Fri Jul  7 2017 antoine.belvire@opensuse.org
- Update to version 0.10.6:
  * All addresses are now unicode strings on all platforms,
    regardless of Python version.
* Fri Mar 31 2017 antoine.belvire@opensuse.org
- Use pypi.io as source url.
* Sat Mar 18 2017 antoine.belvire@opensuse.org
- Update to version 0.10.5:
  * Fix setup.py in case there's no print
  * Fix a potential one-byte stack overwrite
  * Fix possible null pointer deference
  * Respect interface priorities when determining default gateway
  * Use CIDR notation for IPv6 netmasks
  * Ignore broadcast addresses in the 169.254.0.0/16 range
- Convert package to python singlespec.
* Sat May 24 2014 tchvatal@suse.com
- Version bump to 0.10.4:
  * Various small fixes
- Fix source download url
- Fix homepage
* Mon May 12 2014 hpj@urpla.net
- Update to version 0.10.3:
  - Version 0.10.3
    + When using Netlink (i.e. Linux), check for the constant
    NLM_F_DUMP_INTR, since it only appeared in kernel version 3.1
  - Version 0.10.2
    + Added a workaround for broken netlink headers on certain Linux
    distributions (the problem being that the netlink headers fail to
    include <bits/sockaddr.h>, which causes a build failure).
  - Version 0.10.1
    + Fixed a problem with the gateways() function that caused it a
    crash on PyPy.
    + The CI system is now set up to build for PyPy as well, so
    problems will be found sooner.
  - Version 0.10.0
    + Python 3 compatibility.
    + Improved Windows source code compatibility.
    + Added gateway detection via gateways() function.
    + New version number format (skipped 0.9.0 due to its use by
    the netifaces-merged fork).
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Jun 25 2012 saschpe@suse.de
- Update to version 0.8:
  + Fixed bit-rot in the ioctl() code path.
  + Fixed a problem with setup.py that might manifest itself if the
    config.cache file was manually edited.
  + Fixed the ioctl() code path to cope with systems that have sa_len and
    return longer than normal struct ifreq results from SIOCG[L]IFCONF;
* Fri Jun 15 2012 saschpe@suse.de
- Update to version 0.6:
  + Added a workaround for a FreeBSD kernel bug (kern/152036).
  + Added address_families dictionary to allow code to look up the symbolic
    name corresponding to a given numeric address family code.
* Mon Jun 11 2012 saschpe@suse.de
- Spec header cleanup
* Tue Nov 29 2011 saschpe@suse.de
- Minor cleanup
* Thu Jan 27 2011 rschweikert@novell.com
- Initial build to meet swift dependency requirement
